@@ -876,6 +876,10 @@ njs_promise_perform_then(njs_vm_t *vm, njs_value_t *value,
     } else {
         function = njs_promise_create_function(vm,
                                                sizeof(njs_promise_context_t));
+        if (njs_slow_path(function == NULL)) {
+            return NJS_ERROR;
+        }
+
         function->u.native = njs_promise_reaction_job;
 
         if (data->state == NJS_PROMISE_REJECTED) {
@@ -912,6 +916,28 @@ njs_promise_perform_then(njs_vm_t *vm, njs_value_t *value,
 }
 
 
+njs_promise_type_t
+njs_promise_state(const njs_value_t *value)
+{
+    njs_promise_data_t  *promise_data;
+
+    promise_data = njs_data(&njs_promise(value)->value);
+
+    return promise_data->state;
+}
+
+
+njs_value_t *
+njs_promise_result(const njs_value_t *value)
+{
+    njs_promise_data_t  *promise_data;
+
+    promise_data = njs_data(&njs_promise(value)->value);
+
+    return &promise_data->result;
+}
+
+
 static njs_int_t
 njs_promise_prototype_catch(njs_vm_t *vm, njs_value_t *args, njs_uint_t nargs,
     njs_index_t unused, njs_value_t *retval)
@@ -945,6 +971,10 @@ njs_promise_prototype_finally(njs_vm_t *vm, njs_value_t *args, njs_uint_t nargs,
     finally = njs_arg(args, nargs, 1);
 
     function = njs_promise_create_function(vm, sizeof(njs_promise_context_t));
+    if (njs_slow_path(function == NULL)) {
+        return NJS_ERROR;
+    }
+
     function->u.native = njs_promise_constructor;
 
     njs_set_function(&constructor, function);
